# Groot Ansible

Ansible scripts for my own use cases.

# Dev Notes

Some rough guidelines (in much need of explanation).

## Tags, Playbooks, Roles

The following three entities can be used in a variety of ways - e.g. roles and playbooks
both can be used to help share procedures and it is easy to get mixed up about
what to use and what not. Some conventions that I am currently sticking to.

* **Tags** : for dev handles that enable 'mucking around' with what is getting done.
* **Roles** : use as much as possible to share jobs
* **Playbooks** : to script use cases

